from setuptools import setup

setup(name='spsn_probability',
      version='0.1',
      description='Gaussian distributions',
      packages=['spsn_probability'],
      author = 'Sanmeet Pradhan',
      
      zip_safe=False)
